@@ -26,7 +26,7 @@ class Todo(ModelSQL, ModelView):
     _rec_name = 'uuid'
 
     calendar = fields.Many2One('calendar.calendar', 'Calendar',
-            required=True, select=1, ondelete="CASCADE")
+            required=True, select=True, ondelete="CASCADE")
     alarms = fields.One2Many('calendar.todo.alarm', 'todo', 'Alarms')
     classification = fields.Selection([
         ('public', 'Public'),
@@ -38,7 +38,7 @@ class Todo(ModelSQL, ModelView):
             'readonly': Eval('status') != 'completed',
             }, depends=['status'])
     description = fields.Text('Description')
-    dtstart = fields.DateTime('Start Date', select=1)
+    dtstart = fields.DateTime('Start Date', select=True)
     location = fields.Many2One('calendar.location', 'Location')
     organizer = fields.Char('Organizer', states={
             'required': If(Bool(Eval('attendees')),
@@ -46,7 +46,7 @@ class Todo(ModelSQL, ModelView):
             }, depends=['attendees', 'parent'])
     attendees = fields.One2Many('calendar.todo.attendee', 'todo',
             'Attendees')
-    percent_complete = fields.Integer('Percent complete',
+    percent_complete = fields.Integer('Percent complete', required=True,
         states={
             'readonly': ~Eval('status').in_(['needs-action', 'in-process']),
             }, depends=['status'])
@@ -58,15 +58,15 @@ class Todo(ModelSQL, ModelView):
             states={
                 'invisible': Bool(Eval('parent')),
             }, depends=['uuid', 'calendar', 'parent'])
-    recurrence = fields.DateTime('Recurrence', select=1, states={
+    recurrence = fields.DateTime('Recurrence', select=True, states={
             'invisible': ~Eval('_parent_parent'),
             'required': Bool(Eval('_parent_parent')),
             }, depends=['parent'])
-    sequence = fields.Integer('Sequence')
+    sequence = fields.Integer('Sequence', required=True)
     parent = fields.Many2One('calendar.todo', 'Parent',
             domain=[
                 ('uuid', '=', Eval('uuid')),
-                ('parent', '=', False),
+                ('parent', '=', None),
                 ('calendar', '=', Eval('calendar'))
             ],
             ondelete='CASCADE', depends=['uuid', 'calendar'])
@@ -80,17 +80,19 @@ class Todo(ModelSQL, ModelView):
         ], 'Status', on_change=['status', 'completed', 'percent_complete'])
     summary = fields.Char('Summary')
     uuid = fields.Char('UUID', required=True,
-            help='Universally Unique Identifier', select=1)
-    due = fields.DateTime('Due Date', select=1)
+            help='Universally Unique Identifier', select=True)
+    due = fields.DateTime('Due Date', select=True)
     categories = fields.Many2Many('calendar.todo-calendar.category',
             'todo', 'category', 'Categories')
-    exdates = fields.One2Many('calendar.todo.exdate', 'todo', 'Exception Dates',
-            states={
-                'invisible': Bool(Eval('parent')),
+    exdates = fields.One2Many('calendar.todo.exdate', 'todo',
+        'Exception Dates',
+        states={
+            'invisible': Bool(Eval('parent')),
             }, depends=['parent'])
-    exrules = fields.One2Many('calendar.todo.exrule', 'todo', 'Exception Rules',
-            states={
-                'invisible': Bool(Eval('parent')),
+    exrules = fields.One2Many('calendar.todo.exrule', 'todo',
+        'Exception Rules',
+        states={
+            'invisible': Bool(Eval('parent')),
             }, depends=['parent'])
     rdates = fields.One2Many('calendar.todo.rdate', 'todo', 'Recurrence Dates',
             states={
@@ -111,8 +113,9 @@ class Todo(ModelSQL, ModelView):
     def __init__(self):
         super(Todo, self).__init__()
         self._sql_constraints = [
+            #XXX should be unique across all componenets
             ('uuid_recurrence_uniq', 'UNIQUE(uuid, calendar, recurrence)',
-                'UUID and recurrence must be unique in a calendar!'), #XXX should be unique across all componenets
+                'UUID and recurrence must be unique in a calendar!'),
         ]
         self._constraints += [
             ('check_recurrence', 'invalid_recurrence'),
@@ -129,7 +132,7 @@ class Todo(ModelSQL, ModelView):
             model_data_ids = model_data_obj.search([
                 ('fs_id', '=', 'rule_group_read_todo_line3'),
                 ('module', '=', module_name),
-                ('inherit', '=', False),
+                ('inherit', '=', None),
                 ], limit=1)
             if model_data_ids:
                 model_data = model_data_obj.browse(model_data_ids[0])
@@ -150,6 +153,9 @@ class Todo(ModelSQL, ModelView):
         user = user_obj.browse(Transaction().user)
         return user.timezone
 
+    def default_percent_complete(self):
+        return 0
+
     def on_change_status(self, vals):
         res = {}
         if 'status' not in vals:
@@ -177,7 +183,7 @@ class Todo(ModelSQL, ModelView):
         return res
 
     def search_calendar_field(self, name, clause):
-        return [('calendar.' + name[9:],) + tuple(clause[1:])]
+        return [('calendar.' + name[9:],) + clause[1:]]
 
     def check_recurrence(self, ids):
         '''
@@ -200,10 +206,11 @@ class Todo(ModelSQL, ModelView):
 
         res = super(Todo, self).create(values)
         todo = self.browse(res)
-        if todo.calendar.owner \
-                and (todo.organizer == todo.calendar.owner.email \
-                or (todo.parent \
-                and todo.parent.organizer == todo.parent.calendar.owner.email)):
+        if (todo.calendar.owner
+                and (todo.organizer == todo.calendar.owner.email
+                    or (todo.parent
+                        and todo.parent.organizer == \
+                            todo.parent.calendar.owner.email))):
             if todo.organizer == todo.calendar.owner.email:
                 attendee_emails = [x.email for x in todo.attendees
                         if x.status != 'declined'
@@ -221,27 +228,24 @@ class Todo(ModelSQL, ModelView):
                         for calendar_id in calendar_ids:
                             new_id = self.copy(todo.id, default={
                                 'calendar': calendar_id,
-                                'occurences': False,
-                                'uuid': todo.uuid,
+                                'occurences': None,
                                 })
                             for occurence in todo.occurences:
                                 self.copy(occurence.id, default={
                                     'calendar': calendar_id,
                                     'parent': new_id,
-                                    'uuid': occurence.uuid,
                                     })
                     else:
                         parent_ids = self.search([
                             ('uuid', '=', todo.uuid),
                             ('calendar.owner.email', 'in', attendee_emails),
                             ('id', '!=', todo.id),
-                            ('recurrence', '=', False),
+                            ('recurrence', '=', None),
                             ])
                         for parent in self.browse(parent_ids):
                             self.copy(todo.id, default={
                                 'calendar': parent.calendar.id,
                                 'parent': parent.id,
-                                'uuid': todo.uuid,
                                 })
         # Restart the cache for todo
         collection_obj.todo.reset()
@@ -322,7 +326,7 @@ class Todo(ModelSQL, ModelView):
                             ('uuid', '=', todo.uuid),
                             ('calendar.owner.email', 'in', attendee_emails),
                             ('id', '!=', todo.id),
-                            ('recurrence', '=', todo.recurrence or False),
+                            ('recurrence', '=', todo.recurrence),
                             ])
                     for todo2 in self.browse(todo_ids):
                         if todo2.calendar.owner.email in attendee_emails:
@@ -338,27 +342,25 @@ class Todo(ModelSQL, ModelView):
                             for calendar_id in calendar_ids:
                                 new_id = self.copy(todo.id, default={
                                     'calendar': calendar_id,
-                                    'occurences': False,
-                                    'uuid': todo.uuid,
+                                    'occurences': None,
                                     })
                                 for occurence in todo.occurences:
                                     self.copy(occurence.id, default={
                                         'calendar': calendar_id,
                                         'parent': new_id,
-                                        'uuid': occurence.uuid,
                                         })
                         else:
                             parent_ids = self.search([
-                                ('uuid', '=', todo.uuid),
-                                ('calendar.owner.email', 'in', attendee_emails),
-                                ('id', '!=', todo.id),
-                                ('recurrence', '=', False),
-                                ])
+                                    ('uuid', '=', todo.uuid),
+                                    ('calendar.owner.email', 'in',
+                                        attendee_emails),
+                                    ('id', '!=', todo.id),
+                                    ('recurrence', '=', None),
+                                    ])
                             for parent in self.browse(parent_ids):
                                 self.copy(todo.id, default={
                                     'calendar': parent.calendar.id,
                                     'parent': parent.id,
-                                    'uuid': todo.uuid,
                                     })
         # Restart the cache for todo
         collection_obj.todo.reset()
@@ -387,7 +389,7 @@ class Todo(ModelSQL, ModelView):
                             ('uuid', '=', todo.uuid),
                             ('calendar.owner.email', 'in', attendee_emails),
                             ('id', '!=', todo.id),
-                            ('recurrence', '=', todo.recurrence or False),
+                            ('recurrence', '=', todo.recurrence),
                             ])
                         self.delete(todo_ids)
             elif todo.organizer \
@@ -401,7 +403,7 @@ class Todo(ModelSQL, ModelView):
                         ('uuid', '=', todo.uuid),
                         ('calendar.owner.email', '=', organizer),
                         ('id', '!=', todo.id),
-                        ('recurrence', '=', todo.recurrence or False),
+                        ('recurrence', '=', todo.recurrence),
                         ], limit=1)
                     if todo_ids:
                         todo2 = self.browse(todo_ids[0])
@@ -426,7 +428,7 @@ class Todo(ModelSQL, ModelView):
         new_ids = []
         for todo_id in ids:
             current_default = default.copy()
-            current_default.setdefault('uuid', self.default_uuid())
+            current_default['uuid'] = self.default_uuid()
             new_id = super(Todo, self).copy(todo_id, default=current_default)
             new_ids.append(new_id)
 
@@ -447,7 +449,6 @@ class Todo(ModelSQL, ModelView):
         pool = Pool()
         category_obj = pool.get('calendar.category')
         location_obj = pool.get('calendar.location')
-        user_obj = pool.get('res.user')
         alarm_obj = pool.get('calendar.todo.alarm')
         attendee_obj = pool.get('calendar.todo.attendee')
         rdate_obj = pool.get('calendar.todo.rdate')
@@ -476,23 +477,24 @@ class Todo(ModelSQL, ModelView):
         if hasattr(vtodo, 'summary'):
             res['summary'] = vtodo.summary.value
         else:
-            res['summary'] = False
+            res['summary'] = None
         if hasattr(vtodo, 'description'):
             res['description'] = vtodo.description.value
         else:
-            res['description'] = False
+            res['description'] = None
         if hasattr(vtodo, 'percent_complete'):
             res['percent_complete'] = int(vtodo.percent_complete.value)
         else:
-            res['percent_complete'] = False
+            res['percent_complete'] = None
 
         if hasattr(vtodo, 'completed'):
             if not isinstance(vtodo.completed.value, datetime.datetime):
-                res['completed'] = datetime.datetime.combine(vtodo.completed.value,
-                        datetime.time())
+                res['completed'] = datetime.datetime.combine(
+                    vtodo.completed.value, datetime.time())
             else:
                 if vtodo.completed.value.tzinfo:
-                    res['completed'] = vtodo.completed.value.astimezone(tzlocal)
+                    res['completed'] = vtodo.completed.value.astimezone(
+                        tzlocal)
                 else:
                     res['completed'] = vtodo.completed.value
 
@@ -527,7 +529,7 @@ class Todo(ModelSQL, ModelView):
                 else:
                     res['recurrence'] = vtodo.recurrence_id.value
         else:
-            res['recurrence'] = False
+            res['recurrence'] = None
         if hasattr(vtodo, 'status'):
             res['status'] = vtodo.status.value.lower()
         else:
@@ -568,7 +570,7 @@ class Todo(ModelSQL, ModelView):
                 location_id = location_ids[0]
             res['location'] = location_id
         else:
-            res['location'] = False
+            res['location'] = None
 
         res['calendar'] = calendar_id
 
@@ -578,7 +580,7 @@ class Todo(ModelSQL, ModelView):
             else:
                 res['organizer'] = vtodo.organizer.value
         else:
-            res['organizer'] = False
+            res['organizer'] = None
 
         attendees_todel = {}
         if todo:
@@ -758,17 +760,18 @@ class Todo(ModelSQL, ModelView):
         elif hasattr(vtodo, 'due'):
             del vtodo.due
 
-
         if not hasattr(vtodo, 'created'):
             vtodo.add('created')
-        vtodo.created.value = todo.create_date.replace(tzinfo=tzlocal).astimezone(tztodo)
+        vtodo.created.value = todo.create_date.replace(
+            tzinfo=tzlocal).astimezone(tztodo)
         if not hasattr(vtodo, 'dtstamp'):
             vtodo.add('dtstamp')
         date = todo.write_date or todo.create_date
         vtodo.dtstamp.value = date.replace(tzinfo=tzlocal).astimezone(tztodo)
         if not hasattr(vtodo, 'last-modified'):
             vtodo.add('last-modified')
-        vtodo.last_modified.value = date.replace(tzinfo=tzlocal).astimezone(tztodo)
+        vtodo.last_modified.value = date.replace(
+            tzinfo=tzlocal).astimezone(tztodo)
         if todo.recurrence and todo.parent:
             if not hasattr(vtodo, 'recurrence-id'):
                 vtodo.add('recurrence-id')
@@ -816,7 +819,8 @@ class Todo(ModelSQL, ModelView):
 
         vtodo.attendee_list = []
         for attendee in todo.attendees:
-            vtodo.attendee_list.append(attendee_obj.attendee2attendee(attendee))
+            vtodo.attendee_list.append(
+                attendee_obj.attendee2attendee(attendee))
 
         if todo.rdates:
             vtodo.add('rdate')
@@ -858,9 +862,9 @@ class TodoCategory(ModelSQL):
     _name = 'calendar.todo-calendar.category'
 
     todo = fields.Many2One('calendar.todo', 'To-Do', ondelete='CASCADE',
-            required=True, select=1)
+            required=True, select=True)
     category = fields.Many2One('calendar.category', 'Category',
-            ondelete='CASCADE', required=True, select=1)
+            ondelete='CASCADE', required=True, select=True)
 
 TodoCategory()
 
@@ -873,9 +877,9 @@ class TodoRDate(ModelSQL, ModelView):
     _rec_name = 'datetime'
 
     calendar_date = fields.Many2One('calendar.date', 'Calendar Date',
-            required=True, ondelete='CASCADE', select=1)
+            required=True, ondelete='CASCADE', select=True)
     todo = fields.Many2One('calendar.todo', 'Todo', ondelete='CASCADE',
-            select=1, required=True)
+            select=True, required=True)
 
     def init(self, module_name):
         cursor = Transaction().cursor
@@ -945,9 +949,9 @@ class TodoRRule(ModelSQL, ModelView):
     _rec_name = 'freq'
 
     calendar_rrule = fields.Many2One('calendar.rrule', 'Calendar RRule',
-            required=True, ondelete='CASCADE', select=1)
+            required=True, ondelete='CASCADE', select=True)
     todo = fields.Many2One('calendar.todo', 'Todo', ondelete='CASCADE',
-            select=1, required=True)
+            select=True, required=True)
 
     def create(self, values):
         todo_obj = Pool().get('calendar.todo')
@@ -1022,9 +1026,9 @@ class TodoAttendee(ModelSQL, ModelView):
     _inherits = {'calendar.attendee': 'calendar_attendee'}
 
     calendar_attendee = fields.Many2One('calendar.attendee',
-            'Calendar Attendee', required=True, ondelete='CASCADE', select=1)
+        'Calendar Attendee', required=True, ondelete='CASCADE', select=True)
     todo = fields.Many2One('calendar.todo', 'Todo', ondelete='CASCADE',
-            required=True, select=1)
+            required=True, select=True)
 
     def create(self, values):
         todo_obj = Pool().get('calendar.todo')
@@ -1035,10 +1039,11 @@ class TodoAttendee(ModelSQL, ModelView):
         res = super(TodoAttendee, self).create(values)
         attendee = self.browse(res)
         todo = attendee.todo
-        if todo.calendar.owner \
-                and (todo.organizer == todo.calendar.owner.email \
-                or (todo.parent \
-                and todo.parent.organizer == todo.parent.calendar.owner.email)):
+        if (todo.calendar.owner
+                and (todo.organizer == todo.calendar.owner.email
+                    or (todo.parent
+                        and todo.parent.organizer == \
+                            todo.parent.calendar.owner.email))):
             if todo.organizer == todo.calendar.owner.email:
                 attendee_emails = [x.email for x in todo.attendees
                         if x.email != todo.organizer]
@@ -1051,7 +1056,7 @@ class TodoAttendee(ModelSQL, ModelView):
                         ('uuid', '=', todo.uuid),
                         ('calendar.owner.email', 'in', attendee_emails),
                         ('id', '!=', todo.id),
-                        ('recurrence', '=', todo.recurrence or False),
+                        ('recurrence', '=', todo.recurrence),
                         ])
                     for todo_id in todo_ids:
                         self.copy(res, default={
@@ -1096,7 +1101,7 @@ class TodoAttendee(ModelSQL, ModelView):
                             ('todo.calendar.owner.email', 'in',
                                     attendee_emails),
                             ('id', '!=', attendee.id),
-                            ('todo.recurrence', '=', todo.recurrence or False),
+                            ('todo.recurrence', '=', todo.recurrence),
                             ('email', '=', attendee.email),
                             ])
                         self.write(attendee_ids, self._attendee2update(
@@ -1136,7 +1141,7 @@ class TodoAttendee(ModelSQL, ModelView):
                             ('todo.calendar.owner.email', 'in',
                                 attendee_emails),
                             ('id', '!=', attendee.id),
-                            ('todo.recurrence', '=', todo.recurrence or False),
+                            ('todo.recurrence', '=', todo.recurrence),
                             ('email', '=', attendee.email),
                             ])
                         self.delete(attendee_ids)
@@ -1153,7 +1158,7 @@ class TodoAttendee(ModelSQL, ModelView):
                         ('todo.uuid', '=', todo.uuid),
                         ('todo.calendar.owner.email', '=', organizer),
                         ('id', '!=', attendee.id),
-                        ('todo.recurrence', '=', todo.recurrence or False),
+                        ('todo.recurrence', '=', todo.recurrence),
                         ('email', '=', attendee.email),
                         ])
                     if attendee_ids:
@@ -1208,9 +1213,9 @@ class TodoAlarm(ModelSQL):
     _inherits = {'calendar.alarm': 'calendar_alarm'}
 
     calendar_alarm = fields.Many2One('calendar.alarm', 'Calendar Alarm',
-            required=True, ondelete='CASCADE', select=1)
+            required=True, ondelete='CASCADE', select=True)
     todo = fields.Many2One('calendar.todo', 'Todo', ondelete='CASCADE',
-            required=True, select=1)
+            required=True, select=True)
 
     def create(self, values):
         todo_obj = Pool().get('calendar.todo')
